@@ -1,4 +1,4 @@
-#!/bin/bash -ev
+#!/bin/sh -ev
 
 MYSQL="default-libmysqlclient-dev mysql-client"
 POSTGRES="postgresql-client"
@@ -13,6 +13,15 @@ wget https://xpra.org/gpg.asc -O- | apt-key add
 wget https://xpra.org/repos/focal/xpra.list -O - > /etc/apt/sources.list.d/xpra.list
 
 apt-get update --allow-releaseinfo-change-origin
+
+#in github actions env this seems to be preinstalled: https://github.com/actions/virtual-environments/pull/4674
+#and causes the script to break when installing mysql-client with apt.
+if dpkg-query --show  "mysql-client"
+then
+  MYSQL="default-libmysqlclient-dev"
+fi
+
+
 apt-get install --no-install-recommends -y $DEV_ENV $MYSQL $POSTGRES $SQLITE
 apt-get clean
 rm -rf /var/cache/apt/*
