@@ -4,6 +4,8 @@ if [ ! -f /.provisioned ]; then
     # Regenerate host keys
     /bin/rm -fv /etc/ssh/ssh_host_*
     dpkg-reconfigure openssh-server
+    apt-get update -o Dir::Etc::SourceList=/etc/apt/sources.list -o Dir::Etc::SourceParts=/dev/null
+    apt-get install -y ca-certificates
 
     # Secure ssh (we modify its config here after the reconfigure above to avoid it asking about changes to config files)
     echo "PasswordAuthentication no" >> /etc/ssh/sshd_config.d/reahl.conf
@@ -20,19 +22,15 @@ if [ ! -f /.provisioned ]; then
     /etc/init.d/ssh start
 
     # Update localhost known_hosts
-    su $REAHL_USER -c -- bash -l -c 'ssh-keyscan -t rsa localhost > ~/.ssh/known_hosts'
+    su $REAHL_USER -c 'bash -l -c "ssh-keyscan -t rsa localhost > ~/.ssh/known_hosts"'
 
     if [ ! -z "$BOOTSTRAP_REAHL_SOURCE" ]; then
         $REAHL_SCRIPTS/scripts/installBuildDebs.sh
-        su $REAHL_USER -c -- bash -l -c "
-           deactivate
-           rmvirtualenv $VENV_NAME
-           $REAHL_SCRIPTS/scripts/createVenv.sh $VENV_NAME
-           workon $VENV_NAME
+        su $REAHL_USER -c 'bash -l -c "
            cd $BOOTSTRAP_REAHL_SOURCE
-           python3 scripts/bootstrap.py --script-dependencies
-           python3 scripts/bootstrap.py --pip-installs
-        "
+           $VENV/bin/python scripts/bootstrap.py --script-dependencies
+           $VENV/bin/python scripts/bootstrap.py --pip-installs
+        "'
     fi
 
     /etc/init.d/ssh stop
